@@ -26,12 +26,10 @@ class DatasetMixin:
         )
         global_tags = self._get_tags_aspect(dataset.tags)
         owner_aspect = self._get_ownership_aspect(dataset.owners or [self.context.user_email])
-        context = self.context
-        browse_paths = self._get_browse_paths_aspect(dataset.browse_paths or [f'Projects/{context.project}/Datasets'])
         container_aspect = ContainerClass(
             dataset.group
         ) if dataset.group else None
-        self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, browse_paths, container_aspect]))
+        self._emit_aspects(Dataset.entity_type, dataset.urn, filter(None, [dataset_properties, global_tags, owner_aspect, container_aspect]))
         return dataset.urn
 
     def update_dataset(self, dataset: Dataset):
@@ -52,7 +50,6 @@ class DatasetMixin:
             uri=uri,
             tags=tags,
             description=properties.get('description', r.get('description', '')),
-            browse_paths=[os.path.join(*path['path']) for path in r.get('browsePaths', [])],
             properties=custom_properties,
             owners=[o['owner']['urn'].split(':', maxsplit=3)[-1] for o in r.get('ownership', {}).get('owners')],
             group=r.get('container', {}).get('urn'),
