@@ -22,9 +22,7 @@ class DatasetGroupMixin:
         )
         global_tags = self._get_tags_aspect(dataset_group.tags)
         owner_aspect = self._get_ownership_aspect(dataset_group.owners or [self.context.user_email])
-        context = self.context
-        browse_paths = self._get_browse_paths_aspect(dataset_group.browse_paths or [f'Projects/{context.project}/Dataset Groups'])
-        self._emit_aspects(DatasetGroup.entity_type, dataset_group.urn, [dataset_group_properties, global_tags, owner_aspect, browse_paths])
+        self._emit_aspects(DatasetGroup.entity_type, dataset_group.urn, [dataset_group_properties, global_tags, owner_aspect])
         return dataset_group.urn
 
     def update_dataset_group(self, dataset_group: DatasetGroup):
