@@ -43,9 +43,7 @@ class ModelMixin:
         )
         global_tags = self._get_tags_aspect(model.tags)
         owner_aspect = self._get_ownership_aspect(model.owners or [self.context.user_email])
-        context = self.context
-        browse_paths = self._get_browse_paths_aspect(model.browse_paths or [f'Projects/{context.project}/Models'])
-        self._emit_aspects(Model.entity_type, model.urn, [model_properties, global_tags, owner_aspect, browse_paths])
+        self._emit_aspects(Model.entity_type, model.urn, [model_properties, global_tags, owner_aspect])
         return model.urn
 
     def update_model(self, model: Model):
@@ -66,7 +64,6 @@ class ModelMixin:
             uri=uri,
             tags=tags,
             description=properties.get('description', r.get('description', '')),
-            browse_paths=[os.path.join(*path['path']) for path in r.get('browsePaths', [])],
             properties=custom_properties,
             algorithm=properties.get('type'),
             created_at=properties.get('date'),
